---
title: <span class="badge object-type-scalar"></span> RequestsPerMinute
---
# <span class="badge object-type-scalar"></span> RequestsPerMinute

Throughput: requests/min (rpm)

## Definition

```python
# Throughput: requests/min (rpm)
RequestsPerMinute: typing.Literal["reqpm"] = "reqpm"
```
